# frozen_string_literal: true

describe WPScan::DB::Theme do
  describe '#vulnerabilities' do
    # Handled in spec/app/models/theme_spec
  end
end
